@@ -12,7 +12,7 @@ use strict;
 use warnings;
 
 package App::RouterColorizer;
-$App::RouterColorizer::VERSION = '1.222771';
+$App::RouterColorizer::VERSION = '1.222772';
 use Moose;
 
 use feature 'signatures';
@@ -141,7 +141,10 @@ sub _parse_line ( $self, $text ) {
     # Numbers
     # We need to make sure we don't highlight undesirably, such as in an
     # escape sequence.
-    $line =~ s/ ( (?<! [:\.0-9]) (?<! \e \[) [0-9]+ (?! [:0-9]) ) /$self->_numerify($1)/egxx;
+    $line =~ s/ (
+                    (?<! [:\.0-9]) (?<! \e \[) (?<! \e \[\?)
+                    [0-9]+ (?! [:0-9])
+                ) /$self->_numerify($1)/egxx;
 
     return "$preamble$line$trailer$eol";
 }
@@ -603,7 +606,7 @@ App::RouterColorizer - Colorize router CLI output
 
 =head1 VERSION
 
-version 1.222771
+version 1.222772
 
 =head1 DESCRIPTION
 
